# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [16.0.1.1.0] - 2024-07-01
### Changed
- [#46](https://gitlab.com/somitcoop/erp-research/odoo-helpdesk/-/merge_requests/46) Migrate heldesk_ticket_document_pages module v16
## [12.0.2.0.1] - 2024-06-05
### Added
- [#3](https://gitlab.com/somitcoop/erp-research/odoo-helpdesk/-/merge_requests/3) Add heldesk_ticket_document_pages module